import java.awt.*;

/**
   This class displays an percentage bar on a component that can be added to any
   container

   @author David Winchurch.
   @version 09/03/2001
**/

public class PercentageBar extends Component
{
   //The graphics primatives required to double buffer the bar
   private Graphics backSurface;
   private Image backBuffer;

   //flaot that stores the percentage of the bar to fill between 0f and 1f
   private float percentage=0f;

   //The stored color of the bar
   private Color barColor=new Color(0,0,128);

   private String text;

   /**
      Constructor. Does nothing
   **/

   public PercentageBar(String label)
   {
      text=label;
   }

   /**
      Required for pack methods to work

      @returns the prefered size of the component as a Dimension
   **/

   public Dimension getPreferredSize()
   {
      return new Dimension(150,45);
   }

   /**
      Sets the percentage of the bar to display

      @param p the percentage between 0f and 1f
   **/

   public void setPercentage(float p)
   {
      percentage=p;
   }

   /**
      Sets the color of the bar

      @param c the desired color of the bar
   **/

   public void setBarColor(Color c)
   {
      barColor=c;
   }

   /**
      Overwritten paint method. Ensures that the correct image is drawn
      when the program is obscured then revealed

      @param g the specified context to use for updating.
   **/

   public void paint(Graphics g)
   {
      //creates the graphics primatives for the backbuffer provided it will be legal to create them
      if(backBuffer==null && getSize().width>0 && getSize().height>0)
      {
         backBuffer=createImage(getSize().width, getSize().height);
         backSurface=backBuffer.getGraphics();
      }

      //Draws the percentage bar 
      backSurface.clearRect(0,0, 150, 45);
      backSurface.setColor(Color.black);
      backSurface.drawString(text, 3, 18);
      backSurface.setColor(Color.gray);
      backSurface.drawLine(3,28,getSize().width-3,28);
      backSurface.drawLine(3,28,3,41);
      backSurface.setColor(Color.white);
      backSurface.drawLine(3,42,getSize().width-3,42);
      backSurface.drawLine(getSize().width-3,28,getSize().width-3,42);
      backSurface.setColor(barColor);
      backSurface.fillRect(5,30,(int)((float)getSize().width*percentage)-10,11);

      //Draws the backbuffer to the screen
      g.drawImage(backBuffer, 0, 0, Color.gray, this);
   } 
}
